import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;

/**
 * Ein primitives Tastaturspiel.
 * Eine getippter Buchstabe wird fortlaufend wiederholt.
 * 
 * @author Bernd Gramlich
 * @version 2013-05-06
 */
public class Tippspiel implements KeyListener
{
    /*
     * Die Ausgabe.
     */
    private Beschriftung ausgabe;
    
    /*
     * Der Buchstabe und der Ausgabetext.
     */
    private char buchstabe;
    private String ausgabetext;
    
    /*
     * Aufhren?
     */
    private boolean aufhoeren;

    /**
     * Konstruktor.
     * Erzeuge die Ausgabe und warte auf Tastaturereignisse der Leinwand.
     */
    public Tippspiel ()
    {
        ausgabetext = "";
        
        ausgabe = new Beschriftung ();
        ausgabe.setzeInhalt (ausgabetext);
        ausgabe.setzeSchriftgroesse (36);
        ausgabe.setzeFarbe ("grau");
        ausgabe.setzePosition (1, 40);
        ausgabe.macheSichtbar ();
        
        Leinwand.gibLeinwand ().gibFenster ().addKeyListener (this);
        
        buchstabe = 'o';
        aufhoeren = false;
        
        spiele ();
    }
    
    /**
     * Gib solange den aktuellen Buchstaben aus, bis das Endesignal kommt.
     */
    public void spiele ()
    {
        while (!aufhoeren)
        {
            /*
             * Warte eine Zehntelsekunde.
             */
            Leinwand.gibLeinwand ().warte (100);
            
            /*
             * Fge den aktuellen Buchstaben zum Ausgabetext an.
             */
            ausgabetext = ausgabetext + buchstabe;
            
            /*
             * Wenn der Ausgabetext mehr als 20 Zeichen besitzt, gib nur
             * seine letzten 20 Zeichen aus.
             */
            if (ausgabetext.length () > 20)
            {
                ausgabetext = ausgabetext.substring (1);
            }
            
            /*
             * bernimm den Ausgabetext in die Ausgabe.
             */
            ausgabe.setzeInhalt (ausgabetext);
        }
    }
    
    /**
     * Reagiere darauf, dass eine Taste gedrckt wird.
     * 
     * Wenn die Taste die Eingabetaste ist, beende das Spiel.
     */
    public void keyPressed (KeyEvent taste)
    {
        System.out.println ("Gedrckt.");
        
        switch (taste.getKeyCode ())
        {
            case KeyEvent.VK_ENTER: aufhoeren = true; break;
        }
    }
    
    /**
     * Reagiere darauf, dass eine Taste mit einem druckbaren
     * Zeichen gedrckt wird und wieder losgelassen wird.
     * 
     * Nimm das Zeichen als neuen Buchstaben.
     */
    public void keyTyped (KeyEvent taste)
    {
        System.out.println ("Druckbares Zeichen.");
        
        buchstabe = taste.getKeyChar ();
    }
    
    /**
     * Reagiere darauf, dass eine Taste losgelassen wird.
     */
    public void keyReleased (KeyEvent taste)
    {
        System.out.println ("Losgelassen.");     
    }
}